@@ -120,6 +120,14 @@ def xml_formatter_main():
         default=False,
         help="when specified, output will be limited to current terminal width",
     )
+    parser.add_argument(
+        "--superwrap",
+        "--superwrap",
+        dest="superwrap",
+        action="store_true",
+        default=False,
+        help="super wrap mode. widthhint will be disabled in this mode.",
+    )
     parser.add_argument(
         "--timeout",
         dest="timeout",
@@ -129,7 +137,7 @@ def xml_formatter_main():
     )
     args = parser.parse_args()
 
-    if args.nowrap :
+    if args.nowrap:
         args.plain = True
     if args.plain:
         os.environ["force_ansicolor"] = "0"
@@ -138,7 +146,9 @@ def xml_formatter_main():
     TIMEOUT = 1
 
     def interrupted(signal, frame):
-        print("# timeout/no input from STDIN detected.", file=sys.stderr, flush=True)
+        print("# timeout/no input from STDIN detected.",
+              file=sys.stderr,
+              flush=True)
         parser.print_help()
         sys.exit(0)
 
@@ -196,9 +206,9 @@ def xml_formatter_main():
             print("# row :", r, file=sys.stderr, flush=True)
         t = {}
         e = r.get("field", [])
-        if type(e) is not list :
+        if type(e) is not list:
             e = [e]
-        for c in e :
+        for c in e:
             if len(args.includes) > 0:
                 found = False
                 for sect in args.includes:
@@ -212,7 +222,7 @@ def xml_formatter_main():
             if len(args.excludes) > 0:
                 found = False
                 for sect in args.excludes:
-                    for inx in [s for s in sect.split(",") if s]:
+                    for ex in [s for s in sect.split(",") if s]:
                         if re.search(r"{}".format(ex), c.get('@name'),
                                      re.IGNORECASE):
                             found = True
@@ -233,10 +243,11 @@ def xml_formatter_main():
         return 0
 
     xt = xtable.init_from_list(tbl)
-    if args.widthhint or args.page != 2**30:
+    if args.widthhint or args.page != 2**30 or args.superwrap:
         xt = xtable(data=xt.get_data(),
                     header=xt.get_header(),
                     widthhint=args.widthhint,
+                    superwrap=args.superwrap,
                     rowperpage=args.page)
     if args.pivot:
         print(xt.pivot())
@@ -253,7 +264,7 @@ def xml_formatter_main():
     else:
         expr = str(xt)
         termwidth = os.get_terminal_size().columns
-        if args.nowrap :
+        if args.nowrap:
             expr = "\n".join([ln[:termwidth] for ln in expr.splitlines()])
         print(expr)
 
